@@ -267,8 +267,6 @@ class HdDB:
             count_query = build_count_sql(params, from_sql, where_sql)
             count = self.execute(count_query).fetchone()[0]
 
-            logger.info(f"Executing query: {query}")
-
             return {"data": json.loads(data.to_json(orient="records")), "count": count}
 
         except duckdb.Error as e:
@@ -398,10 +396,6 @@ class HdDB:
                     (field["fld___id"], field["id"], field["label"], tbl),
                 )
 
-            logger.info(
-                f"temp_metadata: {self.execute('SELECT * FROM temp_metadata').fetchdf()}"
-            )
-
             # Insertar en hd_fields usando una consulta JOIN, pero siempre usando 'Txt' como tipo
             self.execute(
                 f"""
@@ -665,8 +659,6 @@ class HdDB:
                             data_col  # Keep unmapped columns as is
                         )
 
-                logger.info(f"column_mapping: {column_mapping}")
-
                 # Check if all required columns are present in the data and identify extra columns
                 missing_columns = set(table_column_names) - set(column_mapping.values())
                 extra_columns = set(column_mapping.values()) - set(table_column_names)
@@ -966,10 +958,10 @@ class HdDB:
         try:
             # Verificar si existe la tabla hd_views
             check_query = f"""
-                SELECT table_name 
+                SELECT table_catalog, table_name 
                 FROM information_schema.tables 
-                WHERE table_schema = '{org}__{db}' 
-                AND table_name = 'hd_views'
+                WHERE table_name = 'hd_views' 
+                AND table_catalog = '{org}__{db}'
             """
             result = self.execute(check_query).fetchone()
 
